@@ -1,5 +1,5 @@
 
-/* modified by Martin Hedenfalk <mhe@home.se> 19 aug 2000
+/* modified by Martin Hedenfalk <mhe@home.se> Dec 2002
  */
 
 /*
@@ -37,19 +37,13 @@
 
 #include "syshdr.h"
 
-#if defined(KRB4) || defined(KRB5)
+#ifdef SECFTP
 
 #include "ftp.h"
 #include "base64.h"
 #include "commands.h"
 
-/*RCSID("$Id: security.c,v 1.8 2000/10/20 13:50:18 mhe Exp $");*/
-
-/*static enum protection_level command_prot;*/
-/*static enum protection_level data_prot;*/
-/*static size_t buffer_size;*/
-/*static struct buffer in_buffer, out_buffer;*/
-/*int sec_complete;*/
+/*RCSID("$Id: security.c,v 1.10 2002/12/05 22:12:37 mhe Exp $");*/
 
 static struct
 {
@@ -84,13 +78,13 @@ enum protection_level name_to_level(const char *name)
 }
 
 static struct sec_client_mech *mechs[] = {
-#ifdef KRB5
+#ifdef HAVE_KRB5
 	&gss_client_mech,
 #endif
-#ifdef KRB4
+#ifdef HAVE_KRB4
 	&krb4_client_mech,
 #endif
-#ifdef SSL
+#ifdef USE_SSL
 	&ssl_client_mech,
 #endif
 	NULL
@@ -596,4 +590,4 @@ void sec_end(void)
 	ftp->data_prot = (enum protection_level)0;
 }
 
-#endif /* KRB4 || KRB5 */
+#endif /* SECFTP */
