@@ -1,4 +1,4 @@
-/* $Id: ftpsend.c,v 1.14 2002/11/05 22:51:58 mhe Exp $
+/* $Id: ftpsend.c,v 1.17 2004/05/20 11:10:52 mhe Exp $
  *
  * ftpsend.c -- send/receive files and file listings
  *
@@ -76,20 +76,23 @@ static int ftp_init_transfer(void)
 	unsigned char pac[6];
 
 	if(!ftp_connected())
-		return -1;
+		goto err0;
 
-	ftp->data = sock_create();
+	if (!(ftp->data = sock_create())) {
+		goto err0;
+	}
 	sock_copy(ftp->data, ftp->ctrl);
 
 	if(ftp_is_passive()) {
-		if(ftp_pasv(pac) != 0)
-			return -1;
+		if(ftp_pasv(pac) != 0) {
+			goto err1;
+		}
 
 		sock_getsockname(ftp->ctrl, &sa);
 		memcpy(&sa.sin_addr, pac, (size_t)4);
 		memcpy(&sa.sin_port, pac+4, (size_t)2);
 		if(sock_connect_addr(ftp->data, &sa) == -1)
-			return -1;
+			goto err1;
 	} else {
 		sock_listen(ftp->data);
 
@@ -100,12 +103,17 @@ static int ftp_init_transfer(void)
 		ftp_cmd("PORT %d,%d,%d,%d,%d,%d",
 				a[0], a[1], a[2], a[3], p[0], p[1]);
 		if(ftp->code != ctComplete)
-			return -1;
+			goto err1;
 	}
 
 	sock_throughput(ftp->data);
 
 	return 0;
+
+ err1:
+	sock_destroy(ftp->data);
+ err0:
+	return -1;
 }
 
 int ftp_type(transfer_mode_t type)
@@ -344,7 +352,7 @@ static int FILE_recv_binary(FILE *in, FILE *out)
 		}
 	}
 
-	xfree(buf);
+	free(buf);
 	ftp_set_close_handler();
 
 	return maybe_abort(in, out);
@@ -397,7 +405,7 @@ static int FILE_send_binary(FILE *in, FILE *out)
 	sec_fflush(out);
 #endif
 
-	xfree(buf);
+	free(buf);
 
 	return maybe_abort(in, out);
 }
@@ -458,7 +466,7 @@ static int FILE_recv_ascii(FILE *in, FILE *out)
 		}
 	}
 
-	xfree(buf);
+	free(buf);
 
 	return maybe_abort(in, out);
 }
@@ -503,7 +511,7 @@ static int FILE_send_ascii(FILE *in, FILE *out)
 		}
 	}
 
-	xfree(buf);
+	free(buf);
 
 	return maybe_abort(in, out);
 }
@@ -624,7 +632,7 @@ static int ftp_init_receive(const char *path, transfer_mode_t mode,
 			 */
 			e = strstr(ftp->reply, " bytes");
 			if(e != 0) {
-				while(isdigit((int)e[-1]))
+				while((e > ftp->reply) && isdigit((int)e[-1]))
 					e--;
 				ftp->ti.total_size = atol(e);
 			} /* else we don't bother */
@@ -726,7 +734,7 @@ static int ftp_send(const char *path, FILE *fp, putmode_t how,
 			e += 5;
 			l = strlen(e);
 			if(l) {
-				xfree(ftp->ti.local_name);
+				free(ftp->ti.local_name);
 				if(*e == '\'')
 					ftp->ti.local_name = xstrndup(e+1, l-3);
 				else
@@ -819,11 +827,11 @@ int ftp_fxpfile(Ftp *srcftp, const char *srcfile,
 		rfile *f;
 
 		f = ftp_get_file(destfile);
-		if(f && f->size != (unsigned long)-1)
+		if(f && f->size != (unsigned long long)-1)
 			ftp->restart_offset = f->size;
 		else {
 			ftp->restart_offset = ftp_filesize(destfile);
-			if(ftp->restart_offset == (unsigned long)-1) {
+			if(ftp->restart_offset == (unsigned long long)-1) {
 				ftp_err(_("unable to get remote filesize of '%s',"
 						  " unable to resume\n"),
 						destfile);
@@ -963,7 +971,7 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 	}
 
 	if(rp > 0L) {
-		if(fseek(fp, rp, SEEK_SET) != 0) {
+		if(fseeko(fp, rp, SEEK_SET) != 0) {
 			ftp_err(_("%s: %s, transfer cancelled\n"),
 					outfile, strerror(errno));
 			close_func(fp);
@@ -972,8 +980,8 @@ int ftp_getfile(const char *infile, const char *outfile, getmode_t how,
 		}
 	}
 
-	xfree(ftp->ti.remote_name);
-	xfree(ftp->ti.local_name);
+	free(ftp->ti.remote_name);
+	free(ftp->ti.local_name);
 	ftp->ti.remote_name = xstrdup(infile);
 	ftp->ti.local_name = xstrdup(outfile);
 
@@ -1011,8 +1019,8 @@ int ftp_putfile(const char *infile, const char *outfile, putmode_t how,
 	}
 
 	ftp->ti.total_size = statbuf.st_size;
-	xfree(ftp->ti.remote_name);
-	xfree(ftp->ti.local_name);
+	free(ftp->ti.remote_name);
+	free(ftp->ti.local_name);
 	ftp->ti.remote_name = xstrdup(infile); /* actually local file, or _target_ */
 	ftp->ti.local_name = xstrdup(outfile); /* actually remote file, or _source_ */
 
@@ -1020,11 +1028,11 @@ int ftp_putfile(const char *infile, const char *outfile, putmode_t how,
 		rfile *f;
 
 		f = ftp_get_file(outfile);
-		if(f && f->size != (unsigned long)-1)
+		if(f && f->size != (unsigned long long)-1)
 			ftp->restart_offset = f->size;
 		else {
 			ftp->restart_offset = ftp_filesize(outfile);
-			if(ftp->restart_offset == (unsigned long)-1) {
+			if(ftp->restart_offset == (unsigned long long)-1) {
 				ftp_err(_("unable to get remote filesize of '%s',"
 						  " unable to resume\n"),
 						outfile);
@@ -1036,7 +1044,7 @@ int ftp_putfile(const char *infile, const char *outfile, putmode_t how,
 
 
 	if(ftp->restart_offset > 0L) {
-		if(fseek(fp, ftp->restart_offset, SEEK_SET) != 0) {
+		if(fseeko(fp, ftp->restart_offset, SEEK_SET) != 0) {
 			ftp_err(_("%s: %s, transfer cancelled\n"),
 					outfile, strerror(errno));
 			fclose(fp);
