@@ -1,4 +1,4 @@
-/* $Id: rglob.c,v 1.6 2002/12/02 14:32:21 mhe Exp $
+/* $Id: rglob.c,v 1.8 2004/05/20 11:10:52 mhe Exp $
  *
  * rglob.c -- remote glob functions
  *
@@ -75,7 +75,7 @@ int rglob_glob(list *gl, const char *mask, bool cpifnomatch,
 	else unquote(d);
 
 	rdir = ftp_get_directory(d);
-	xfree(d);
+	free(d);
 
 	if(rdir) {
 		lip = rdir->files->first;
@@ -116,7 +116,7 @@ int rglob_glob(list *gl, const char *mask, bool cpifnomatch,
 		bool ignore_item;
 
 		if(!cpifnomatch || mp == 0 || *mp == 0 || contains_wildcards(mp)) {
-			xfree(mp);
+			free(mp);
 			return -1;
 		}
 		p = ftp_path_absolute(path);
@@ -133,19 +133,19 @@ int rglob_glob(list *gl, const char *mask, bool cpifnomatch,
 			rfile_fake(nfi, p);
 			list_additem(gl, (void *)nfi);
 		}
-		xfree(p);
+		free(p);
 	}
 
-	xfree(mp);
-	xfree(path);
+	free(mp);
+	free(path);
 	return 0;
 }
 
 /* computes the total size (in bytes) of the files in (rglob list) GL */
-unsigned long rglob_size(list *gl)
+unsigned long long rglob_size(list *gl)
 {
 	listitem *li;
-	unsigned long size = 0;
+	unsigned long long size = 0;
 
 	li = gl->first;
 	while(li) {
@@ -156,10 +156,10 @@ unsigned long rglob_size(list *gl)
 }
 
 /* returns number of directories in GL */
-unsigned long rglob_numdirs(list *gl)
+unsigned long long rglob_numdirs(list *gl)
 {
 	listitem *li;
-	unsigned long n = 0;
+	unsigned long long n = 0;
 
 	li = gl->first;
 	while(li) {
